==> haskell-zinza-0.2-162-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-53tDlsidqIRBYoxvGU8pQx
key:                  zinza-0.2-53tDlsidqIRBYoxvGU8pQx
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  707d4d830fdf0f3393b0638e5f831b6b
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-53tDlsidqIRBYoxvGU8pQx
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zinza-0.2-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-DgTxvK3anO1XiF1G68lci
key:                  zinza-0.2-DgTxvK3anO1XiF1G68lci
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  1b65831b9092369b456ac89e8134b163
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.0.2/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-DgTxvK3anO1XiF1G68lci
depends:
    base-4.15.1.0 containers-0.6.4.1 parsec-3.1.14.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
